# Installation

pip install polygon_data_generator

# Get started
currency_pairs = [["AUD", "USD", [], portfolio("AUD", "USD")]] \
location = os.getcwd() \
print(location) \
data_writer(currency_pairs)